@@ -361,4 +361,5 @@ class   Phial(object):
         self.__flask.run(host         = self.__settings.FLASK_LISTEN_ADDRESS,
                          port         = self.__settings.FLASK_LISTEN_PORT,
                          debug        = self.__settings.FLASK_DEBUG,
-                         use_reloader = self.__settings.FLASK_USE_RELOADER)
+                         use_reloader = self.__settings.FLASK_USE_RELOADER,
+                         threaded     = getattr(self.__settings, 'FLASK_THREADED_DEBUG_SERVER', False))
